//+------------------------------------------------------------------+
//|                                      SX Trendliner               |
//|                                      sorrex@zoznam.sk            |
//+------------------------------------------------------------------+
// 
// 1. psmeno - T = TL = trendline
//              H = HL = horizontlna linka
//              !!!  pretoe spracovanie HL a TL je v programe odlin, treba ho dodriava - inak ich ignoruje alebo spracuje zle
// 
// 2. psmeno - R = restistance
//              S = support
//              EX= exit - okamit uzavretie pozcie bez ohadu na cenu (vhodn pre manulne zatvorenie obchodu v testeri)
//              SL - stop_loss
//              TP - take_profit
//
// 3. psmeno - X = break - prelomenie - k prslune trendovej linke je automaticky vytvoren ochrann zna v rke parametra BAND_value,
//                                       za ktorou je vytvoren paraleln linka s nzvom "RX trigger". Pri jeho prerazen sa otvra pozcia
//              S = scalper            - pecilna TL, pouvan pri skalpovacej metde:
//                                       K linke s vytvoren dve paralely: 1. "soft T_SL" vo vzdialenosti parametru SL_soft
//                                                                          2. "T_SL" vo vzdialenosti SL_hard
//                                       "soft T_SL" je mkkm stoploss-om  - po jeho prelomen sa prestav take_profit linka "H_TP" na min. hodnotu (TP_min)
//                                                                          ak je obchod v strate, nech sa otvoren (poksi sa ete zavre s min. profitom)
//                                                                          ak je v pluse, zavrie ho to
//                                       "T_SL" je tvrd stoploss           po jej prolomen so obchod okamite zavre
//                                       oboma linkami je mon samozrejme hba a upravi si tak operatvne dan rovne priamo v grafe
//
//              A - alarm              - spust alarm (nefunguje v testeri, iba v deme alebo live)
//
// TR     - TL resistance                     - SELL pri dotyku (odraze)   - trendline              
// TS     - TL support                        - BUY pri dotyku (odraze)    - trendline                     
// HR     - HL resistance                     - SELL pri dotyku (odraze)   - horizontlna linka -  (BUY LIMIT prkaz)
// HS     - HL support                        - BUY pri dotyku (odraze)    - horizontlna linka -  (SELL LIMIT prkaz)
//
// TRX    - TL resistance break               - po zakreslen sa vytvor sa paralela "RX Trigger" vo vzdialenosti BAND_value. Po prelomen "RX Trigger" sa TRX premenuje na HR. 
//                                              Obchod sa tak otvor a pri nvrate k pvodnej TRX (teraz HR) odspodu (skoro vdy).
//                                              
// TSX    - TL support break                  - opane ako TRX
//
// HRX    - HL horizontal resistance break    - po prelomen horizont. linky smerom nahol (resistance) sa otvor BUY pozcia (BUY STOP prkaz)
// HSX    - HL horizontal support break       - po prelomen horizont. linky smerom nadol (supportu) sa otvor SELL pozcia (SELL STOP prkaz) 
//
// TRS    - TL scalper resistance             - funguje ako TR, ale po otvoren pozcie sa aut. vytvori T_SL vo vzdialenosti  SL_hard od TL
//                                              a soft_T_SL, ktor pri dotyku zmen TRS na T_TP
// TSS    - TL scalper support                - funguje ako TS, ale po otvoren pozcie sa aut. vytvori T_SL vo vzdialenosti  SL_hard od TL
//                                              a soft_T_SL, ktor pri dotyku zmen TSS na T_TP
//
// T_SL    - psychologick StopLoss            - virtulny SL vo forme trendline - pri dosiahnut uzavrie pozciu 
// T_TP    - psychologick TargetPoint         - virtulny TP vo forme trendline - pri dosiahnut uzavrie pozciu
//
// H_TP    - psychologick StopLoss            - virtulny SL vo forme horizontlnej linky - pri dosiahnut uzavrie pozciu
// H_TP    - psychologick TargetPoint         - virtulny TP vo forme horizontlnej linky - pri dosiahnut uzavrie pozciu
//
// HEX    - exit                              - okamit uzavretie (vhodn pri manulnych backtestoch v testeri)
//                                            - pre manulne okamit otvorenie obchodu v testeri je mon poui HS umiestnen nad cenu (prkaz BUY)
//                                              alebo HR umiestnen pod cenu (SELL)
//
// TSA    - TL resistance  "ALARM"            - rovnak ako TR, ale pri prelomen vyd zvukov signl miesto SELL
// TRA    - TL support "ALARM"                - rovnak ako TS, ale pri prelomen vyd zvukov signl miesto BUY
// HSA    - HL resistance  "ALARM"            - rovnak ako HR, ale pri prelomen vyd zvukov signl miesto SELL
// HRA    - HL support "ALARM"                - rovnak ako HS, ale pri prelomen vyd zvukov signl miesto BUY
// 
//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
#define MAGICMA  0

//---- input parameters

extern double BAND_value         = 3.0;            // vzdialenos paralelnej linky pri RX a SX breakoch
extern double TP_init            = 70.0;           // poiaton TP
extern double SL_hard            = 40.0;           // poiaton SL
extern bool   SL_soft_enable     = False;          // aktivcia funkcie SL_soft - po jej dosiahnut sa TP presunie na hodnotu TP_min, aby sa pozcia uzavrela s min. stratou
extern double SL_soft            = 10;             // hodnota, pri ktorej sa presunie TP na min. hodnotu
extern double TP_min             = 2;              // hodnota, na ktor sa presunie TP pri dosiahnut SL_soft (BE + TP_min)
extern bool   SL_be_enable       = True;           // aktivcia funkcie Breakevent - presunutia SL na TP_min po dosiahnut urithoi zisku (SL_be_pips)
extern double SL_be_pips         = 15;             // hodnota potrebn na na presunutie SL na TP_min
extern bool   Alarm_enable       = True;           // aktivcia funkcie ALARM
extern bool   Cancel_after_open  = True;           // po otvoren obchodu, premenuje aktvnu TL tak, aby sa stala neaktvnou. V opanom prpade by po uzavret obchodu spustila al.
extern double MaximumRisk        = 0.03;           // money management - percento rizika - len ak nie je stanoven fix. vekos. Zohaduje max. vekos straty poda SL_hard
extern double FixLotSize         = 0.5;            // hodnota pre fixn vekos objednvky, ak = 0 - pouije sa MM poda MaximumRisk percenta

       bool   Active_SL_be = false;
       color  sl_color           = Red; 
       color  tp_color           = Chartreuse; 
       color  open_color         = Blue; 
       color  s_color            = YellowGreen; 
       color  r_color            = FireBrick;
       color  a_color            = Magenta;

       double last_SL, last_TP; 
       color  LabelColor         = Silver;


//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
  {
   ObjectCreate("infotext", OBJ_LABEL, 0, 0, 0);
   ObjectSet("infotext", OBJPROP_XDISTANCE, 10);
   ObjectSet("infotext", OBJPROP_YDISTANCE, 20);
   ObjectSet("infotext", OBJPROP_CORNER, 1);
   ObjectSetText("infotext", "", 8, "Arial", LabelColor);
   return(0);
  }
//+------------------------------------------------------------------+
//| expert deinitialization function                                 |
//+------------------------------------------------------------------+
int deinit()
  {
   ObjectDelete  ("infotext"); 
   return(0);
  }
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
  {
//   DrawBorders();
   SetLinesColors();
   

   CheckForAlarm();
   
   if(CalculateCurrentOrders(Symbol())==0) 
      {  
         RemoveHLines();
         CheckForOpen();
      }
   else
         CheckForClose();
     
     
     
//----
   return(0);
  }
//+--------------------------------------------------------------------------------------------------------------------------------------+
//|                                                                     Calculate open positions                                         |
//+--------------------------------------------------------------------------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+--------------------------------------------------------------------------------------------------------------------------------------+
//|                                                                     Calculate optimal lot size                                       |
//+--------------------------------------------------------------------------------------------------------------------------------------+
double LotsOptimized()
  {   double lotsize=0.1;
      double lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/SL_hard*lotsize,1);
      if(lot<0.1) lot=0.1;
      if (FixLotSize>0) lot=FixLotSize;
      return(lot);
  }
     
//+------------------------------------------------------------------------------------------------------------------------------------+
//|                                                                        Check for Alarm conditions                                  |
//+------------------------------------------------------------------------------------------------------------------------------------+
void CheckForAlarm ()
    {  
   if((ObjectFind("TSA")>=0) && (Bid <= ObjectGetValueByShift("TSA", 0)))  
         Alarm ("Sound1", "Prelomenie trendline TSA");
   if((ObjectFind("TRA")>=0) && (Bid >= ObjectGetValueByShift("TRA", 0)))  
         Alarm ("Sound2", "Prelomenie trendline TRA");
   if((ObjectFind("HSA")>=0) && (Bid <= ObjectGet("HSA",OBJPROP_PRICE1)))  
         Alarm ("Sound1", "Prelomenie rovne HSA");
   if((ObjectFind("HRA")>=0) && (Bid >= ObjectGet("HRA",OBJPROP_PRICE1)))  
         Alarm ("Sound2", "Prelomenie rovne HRA");
    }

//+------------------------------------------------------------------------------------------------------------------------------------+
//|                                                                        Check for open order conditions                             |
//+------------------------------------------------------------------------------------------------------------------------------------+

void CheckForOpen()
  {
int ticket;
//--------------------------------------------------------------------------------------------------------------- buy conditions
   if((ObjectFind("TS")>=0) && (Bid <= ObjectGetValueByShift("TS", 0)))  
     {   OpenNewOrder (Symbol(),OP_BUY,Ask,0,0);
         if (Cancel_after_open)  RenameTL ("TS", "Support Canceled");
     }

   if((ObjectFind("HS")>=0) && (Bid <= ObjectGet("HS",OBJPROP_PRICE1)))  
     {   OpenNewOrder (Symbol(),OP_BUY,Ask,0,0);
         if (Cancel_after_open)  RenameHL ("HS", "Support Canceled");
     }

   if((ObjectFind("HRX")>=0) && (Bid >= ObjectGet("HRX",OBJPROP_PRICE1)))  
     {   OpenNewOrder (Symbol(),OP_BUY,Ask,0,0);
         if (Cancel_after_open)  RenameHL ("HRX", "Resist Canceled");
     }

   if((ObjectFind("RX trigger")>=0) && (Bid >= ObjectGetValueByShift("RX trigger", 0)))  
         RenameTL ("TRX", "TS");

   if((ObjectFind("TSS")>=0) && (Bid <= ObjectGetValueByShift("TSS", 0)))  
     {   OpenNewOrder (Symbol(),OP_BUY,Ask,0,0);
         if (SL_soft_enable) CreateLine("soft T_SL",  ObjectGet("TSS", OBJPROP_TIME1), ObjectGet("TSS", OBJPROP_PRICE1)-SL_soft*Point, ObjectGet("TSS", OBJPROP_TIME2), ObjectGet("TSS", OBJPROP_PRICE2)-SL_soft*Point, STYLE_DOT, 1, sl_color);
         CreateLine("T_SL",       ObjectGet("TSS", OBJPROP_TIME1), ObjectGet("TSS", OBJPROP_PRICE1)-SL_hard*Point, ObjectGet("TSS", OBJPROP_TIME2), ObjectGet("TSS", OBJPROP_PRICE2)-SL_hard*Point, STYLE_SOLID, 1, sl_color);
         if (Cancel_after_open)  RenameTL ("TSS", "Support Canceled");
     }
         
//--------------------------------------------------------------------------------------------------------------- sell conditions
   if((ObjectFind("TR")>=0) && (Bid >= ObjectGetValueByShift("TR", 0)))  
     {   OpenNewOrder (Symbol(),OP_SELL,Bid,0,0);
         if (Cancel_after_open)  RenameTL ("TR", "Resist Canceled");
     }

   if((ObjectFind("HR")>=0) && (Bid >= ObjectGet("HR",OBJPROP_PRICE1)))  
     {   OpenNewOrder (Symbol(),OP_SELL,Bid,0,0);
         if (Cancel_after_open)  RenameHL ("HR", "Resist Canceled");
     }

   if((ObjectFind("HSX")>=0) && (Bid <= ObjectGet("HSX",OBJPROP_PRICE1)))  
     {   OpenNewOrder (Symbol(),OP_SELL,Bid,0,0);
         if (Cancel_after_open)  RenameHL ("HSX", "Support Canceled");
     }

   if((ObjectFind("SX trigger")>=0) && (Bid <= ObjectGetValueByShift("SX trigger", 0)))  
         RenameTL ("TSX", "TR");

   if((ObjectFind("TRS")>=0) && (Bid >= ObjectGetValueByShift("TRS", 0)))  
     {   OpenNewOrder (Symbol(),OP_SELL,Bid,0,0);
         if (SL_soft_enable) CreateLine("soft T_SL",  ObjectGet("TRS", OBJPROP_TIME1), ObjectGet("TRS", OBJPROP_PRICE1)+SL_soft*Point, ObjectGet("TRS", OBJPROP_TIME2), ObjectGet("TRS", OBJPROP_PRICE2)+SL_soft*Point, STYLE_DOT, 1, sl_color);
         CreateLine("T_SL",       ObjectGet("TRS", OBJPROP_TIME1), ObjectGet("TRS", OBJPROP_PRICE1)+SL_hard*Point, ObjectGet("TRS", OBJPROP_TIME2), ObjectGet("TRS", OBJPROP_PRICE2)+SL_hard*Point, STYLE_SOLID, 1, sl_color);
         if (Cancel_after_open)  RenameTL ("TRS", "Resist Canceled");
     }
  }

//+------------------------------------------------------------------------------------------------------------------------------------+
//|                                                                           Check for close order conditions                         |
//+------------------------------------------------------------------------------------------------------------------------------------+
void CheckForClose()
  { 
   bool error = false;
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
      //--------------------------------------------------------------------------------------------------------------- Close buy orders
     if(OrderType()==OP_BUY)
        {
         if((Active_SL_be == True) && ( OrderProfit()/(OrderLots()*10) > SL_be_pips))
               {   SetLevels (0, OrderOpenPrice(), OrderOpenPrice()+TP_min*Point, OrderTakeProfit());
                   Active_SL_be = false;
               }
         if(SL_soft_enable && ObjectFind("TS")>=0 && ((-1)*OrderProfit()/(OrderLots()*10) >= SL_soft))     // SL_soft reached -> move TP to min 
              {      SetLevels (0, OrderOpenPrice(), OrderStopLoss(), OrderOpenPrice()+TP_min*Point);
//                     RenameTL ("TS", "Support Canceled");
              }
         if (ObjectFind("EX")>=0)                  OrderCloseNow (OrderTicket(),OrderLots(),Bid, "EX");
         if (ObjectFind("H_TP")>=0 && Bid>=ObjectGet("H_TP",OBJPROP_PRICE1))      OrderCloseNow (OrderTicket(),OrderLots(),Bid, "Hit buy TP");
         if (ObjectFind("T_TP")>=0 && Bid>=ObjectGetValueByShift("T_TP",0))      OrderCloseNow (OrderTicket(),OrderLots(),Bid, "Hit buy T_TP");
         if (ObjectFind("H_SL")>=0 && Bid<=ObjectGet("H_SL",OBJPROP_PRICE1)) 
              {      OrderCloseNow (OrderTicket(),OrderLots(),Bid, "Hit buy SL");
                     RenameTL ("TS", "Support Canceled");
              }
         if (ObjectFind("T_SL")>=0 && Bid<=ObjectGetValueByShift("T_SL",0)) 
              {      OrderCloseNow (OrderTicket(),OrderLots(),Bid, "Hit buy T_SL");
                     RenameTL ("TR", "Resist Canceled");
                     ObjectDelete ("T_SL");
              }
         if (ObjectFind("soft T_SL")>=0 && Bid<=ObjectGetValueByShift("soft T_SL",0)) 
              {      RenameTL ("TSS", "T_TP");
                     ObjectDelete ("soft T_SL");
              }
         if(CalculateCurrentOrders(Symbol())==0)     RemoveHLines();
         break;
        }

      //--------------------------------------------------------------------------------------------------------------- Close sell orders
      if(OrderType()==OP_SELL)
        {
         if((Active_SL_be == True) && ( OrderProfit()/(OrderLots()*10) > SL_be_pips))
               {   SetLevels (0, OrderOpenPrice(), OrderOpenPrice()-TP_min*Point, OrderTakeProfit());
                   Active_SL_be = false;
               }
         if(SL_soft_enable && ObjectFind("TR")>=0 && ((-1)*OrderProfit()/(OrderLots()*10) >= SL_soft))
              {      SetLevels (0, OrderOpenPrice(), OrderStopLoss(), OrderOpenPrice()-TP_min*Point);
//                     RenameTL ("TR", "Resist Canceled");
              }
         if (ObjectFind("H_TP")>=0 && Bid<=ObjectGet("H_TP",OBJPROP_PRICE1))      OrderCloseNow (OrderTicket(),OrderLots(),Ask, "Hit sell TP");
         if (ObjectFind("T_TP")>=0 && Bid<=ObjectGetValueByShift("T_TP",0))     OrderCloseNow (OrderTicket(),OrderLots(),Ask, "Hit sell T_TP");
         if (ObjectFind("H_SL")>=0 && Bid>=ObjectGet("H_SL",OBJPROP_PRICE1)) 
              {      OrderCloseNow (OrderTicket(),OrderLots(),Ask, "Hit sell SL");
                     RenameTL ("TS", "Resist Canceled");
              }
         if (ObjectFind("T_SL")>=0 && Bid>=ObjectGetValueByShift("T_SL",0)) 
              {      OrderCloseNow (OrderTicket(),OrderLots(),Ask, "Hit sell T_SL");
                     RenameTL ("TS", "Support Canceled");
                     ObjectDelete ("T_SL");
              }
         if (ObjectFind("soft T_SL")>=0 && Bid>=ObjectGetValueByShift("soft T_SL",0)) 
              {      RenameTL ("TRS", "T_TP");
                     ObjectDelete ("soft T_SL");
              }
         if(CalculateCurrentOrders(Symbol())==0)     RemoveHLines();
         break;
        }
      }
  }

//+------------------------------------------------------------------------------------------------------------------------------------+
//|                                                                           ORDER functions                                          |
//+------------------------------------------------------------------------------------------------------------------------------------+
void OpenNewOrder (string symbol, int cmd, double price, double stoploss, double takeprofit)
  {   int   ticket;
      ticket= OrderSend(symbol, cmd, LotsOptimized(), price,1,0,0,"",MAGICMA,0,Blue);
      if ( cmd == OP_BUY)     SetLevels (ticket, Ask, Ask-SL_hard*Point, Ask+TP_init*Point);
      else                    SetLevels (ticket, Bid, Bid+SL_hard*Point, Bid-TP_init*Point);
      Active_SL_be = SL_be_enable;
      PlaySound("news.wav");          
//    SendMail (message, "");               // not working - just idea
      return;
  }

void OrderCloseNow(int ticket, double lots, double price, string reason)
  {   
      OrderClose(ticket, lots, price, 1, Blue);
      PlaySound("news.wav");          
      return;
  }
  
//+------------------------------------------------------------------------------------------------------------------------------------+
//|                                                                           TL  a HL functions                                       |
//+------------------------------------------------------------------------------------------------------------------------------------+
void SetLevels (int ticket, double open, double sl, double tp)
  {   if (sl>0)   CreateHLine("H_SL", sl, STYLE_SOLID, 1, sl_color, "Stop limit");
      if (tp>0)   CreateHLine("H_TP", tp, STYLE_SOLID, 1, tp_color, "Target limit");
//      if (ticket != 0)     OrderModify(ticket, open, sl, tp, 0, CLR_NONE);
   Comment (sl, tp,SL_hard, TP_init);
  }
      
void RemoveHLines()
  {   if (ObjectFind("H_SL")>=0)         ObjectDelete("H_SL");
      if (ObjectFind("T_SL")>=0)        ObjectDelete("T_SL");
      if (ObjectFind("soft T_SL")>=0)   ObjectDelete("soft T_SL");
	   if (ObjectFind("H_TP")>=0)         ObjectDelete("H_TP");
	   if (ObjectFind("T_TP")>=0)        ObjectDelete("T_TP");
  }

void CreateHLine(string name, double p1, int style, int width, 
                 color col, string description)
  {  ObjectDelete(name);
	  ObjectCreate(name, OBJ_HLINE, 0, CurTime(), p1);
	  ObjectSet(name, OBJPROP_COLOR	, col);
	  ObjectSet(name, OBJPROP_STYLE	, style);
	  ObjectSet(name, OBJPROP_WIDTH	, width);
	  ObjectSetText(name, description, 8);
  }

void CreateLine(string name, datetime t1, double p1, datetime t2, 
                double p2, int style, int width, color col)
  {  ObjectDelete(name);
	  ObjectCreate(name, OBJ_TREND, 0, t1, p1, t2, p2);
	  ObjectSet(name, OBJPROP_COLOR	, col	);
	  ObjectSet(name, OBJPROP_RAY		, false);
	  ObjectSet(name, OBJPROP_STYLE	, style);
	  ObjectSet(name, OBJPROP_WIDTH	, width);
	  ObjectSet(name, OBJPROP_RAY	, true);
  }

void SetLinesColors()
  {  string    txt = "Active = "; 
     
     if (ObjectFind("TS")>=0)          {txt = txt+"  TS";    SetLineColor("TS", s_color, STYLE_DASH);}
     if (ObjectFind("TR")>=0)          {txt = txt+"  TR";    SetLineColor("TR", r_color, STYLE_DASH);}
     if (ObjectFind("HS")>=0)          {txt = txt+"  HS";    SetLineColor("HS", s_color, STYLE_DASH);}
     if (ObjectFind("HR")>=0)          {txt = txt+"  HR";    SetLineColor("HR", r_color, STYLE_DASH);}
     if (ObjectFind("HSX")>=0)         {txt = txt+"  HSX";   SetLineColor("HSX", s_color, STYLE_DASH);}
     if (ObjectFind("HRX")>=0)         {txt = txt+"  HRX";   SetLineColor("HRX", r_color, STYLE_DASH);}
     if (ObjectFind("TSS")>=0)         {txt = txt+"  TSS";   SetLineColor("TSS", s_color, STYLE_DASH);}
     if (ObjectFind("TRS")>=0)         {txt = txt+"  TRS";   SetLineColor("TRS", r_color, STYLE_DASH);}
     if (ObjectFind("Support Canceled")>=0)  {               SetLineColor("Support Canceled", s_color, STYLE_SOLID);}
     if (ObjectFind("Resist Canceled")>=0)   {               SetLineColor("Resist Canceled", r_color, STYLE_SOLID);}
     if (ObjectFind("H_SL")>=0)         {txt = txt+"  H_SL"; SetLineColor("H_SL", sl_color, STYLE_SOLID);}
     if (ObjectFind("T_SL")>=0)         {txt = txt+"  T_SL"; SetLineColor("T_SL", sl_color, STYLE_SOLID);}
     if (ObjectFind("H_TP")>=0)         {txt = txt+"  H_TP"; SetLineColor("H_TP", tp_color, STYLE_SOLID);}
     if (ObjectFind("T_TP")>=0)         {txt = txt+"  T_TP"; SetLineColor("T_TP", tp_color, STYLE_SOLID);}
     if (ObjectFind("TRA")>=0)          {txt = txt+"  TRA";  SetLineColor("TRA", a_color, STYLE_SOLID);}
     if (ObjectFind("TSA")>=0)          {txt = txt+"  TSA";  SetLineColor("TSA", a_color, STYLE_SOLID);}
     if (ObjectFind("HRA")>=0)          {txt = txt+"  HRA";  SetLineColor("HRA", a_color, STYLE_SOLID);}
     if (ObjectFind("HSA")>=0)          {txt = txt+"  HSA";  SetLineColor("HSA", a_color, STYLE_SOLID);}

     if (ObjectFind("TSX")>=0)          {txt = txt+" TSX";    SetLineColor("TSX", s_color, STYLE_SOLID);
                                        CreateLine("SX trigger", ObjectGet("TSX", OBJPROP_TIME1), ObjectGet("TSX", OBJPROP_PRICE1)-BAND_value*Point, ObjectGet("TSX", OBJPROP_TIME2), ObjectGet("TSX", OBJPROP_PRICE2)-BAND_value*Point, STYLE_DOT, 1, s_color);
                                       }
                                 else  ObjectDelete("SX trigger");
     if (ObjectFind("TRX")>=0)          {txt = txt+" TRX";    SetLineColor("TRX", r_color, STYLE_SOLID);
                                        CreateLine("RX trigger", ObjectGet("TRX", OBJPROP_TIME1), ObjectGet("TRX", OBJPROP_PRICE1)+BAND_value*Point, ObjectGet("TRX", OBJPROP_TIME2), ObjectGet("TRX", OBJPROP_PRICE2)+BAND_value*Point, STYLE_DOT, 1, r_color);
                                       }
                                 else  ObjectDelete("RX trigger");

     if (txt != "Active = ")  ObjectSetText("infotext", txt, 8, "Arial", Red);
     else                             ObjectSetText("infotext", txt+" NONE", 8, "Arial", Silver);

  }


void SetLineColor(string name, color col, int style)
  {   if(ObjectFind(name)>=0)
        {  ObjectSet(name, OBJPROP_COLOR	, col);
           ObjectSet(name, OBJPROP_STYLE	, style);
        }      
  }
 
void RenameTL(string OldName, string NewName)
    {  if(ObjectFind(OldName)>=0)
         {  CreateLine(NewName, ObjectGet(OldName, OBJPROP_TIME1), ObjectGet(OldName, OBJPROP_PRICE1), ObjectGet(OldName, OBJPROP_TIME2), ObjectGet(OldName, OBJPROP_PRICE2), STYLE_SOLID, 1, FireBrick);
            ObjectDelete(OldName);
         }
    }
void RenameHL(string OldName, string NewName)
    {  if(ObjectFind(OldName)>=0)
         {  CreateHLine(NewName, ObjectGet(OldName, OBJPROP_PRICE1), STYLE_SOLID, 1, FireBrick, NewName);
            ObjectDelete(OldName);
         }
    }
    
void Alarm (string soundtype, string message)
    { if (Alarm_enable)
         { 
//             Alert (message);
               if (soundtype == "Sound1")  PlaySound("news.wav");          
               if (soundtype == "Sound2")  PlaySound("alert2.wav");          
//             SendMail (message, "");               // not working - just idea - you can send "message", price etc
         }
    }


